/****************************************************************************************
 Additional masks and macro definitions that are missed in 'defBF537.h'
 to allow the programmer to use symbolic names for register-access and bit-manipulation 
****************************************************************************************/

#if __VISUALDSPVERSION__ <= 0x05000300

/* ********************** PLL AND RESET MASKS *************************************** */
/* SYSCR Masks */
#define BMODE_BYPASS            0x0000              /* Bypass boot ROM, execute from 16-bit external memory */
#define BMODE_FLASH             0x0001              /* Use Boot ROM to load from 8-bit or 16-bit flash */
#define BMODE_SPIMEM            0x0003              /* Boot from serial SPI memory */
#define BMODE_SPIHOST           0x0004              /* Boot from SPI0 host (slave mode) */
#define BMODE_TWIMEM            0x0005              /* Boot from serial TWI memory */
#define BMODE_TWIHOST           0x0006              /* Boot from TWI0 host (slave mode) */
#define BMODE_UARTHOST          0x0007              /* Boot from UART0 host */


/* **********************  SDRAM CONTROLLER MASKS  *************************** */
/* EBIU_SDBCTL Masks */
#define EBSZ                    0x000E              /* SDRAM external bank size */
#define EBCAW                   0x0030              /* SDRAM external bank column address width */

/* EBIU_SDGCTL Masks */
#define CL                      0x0000000C          /* SDRAM CAS latency */
#define PASR                    0x00000030          /* SDRAM partial array self-refresh */
#define TRAS                    0x000003C0          /* SDRAM tRAS in SCLK cycles */
#define TRP                     0x00003800          /* SDRAM tRP in SCLK cycles */
#define TRCD                    0x00030000          /* SDRAM tRCD in SCLK cycles */
#define TWR                     0x00180000          /* SDRAM tWR in SCLK cycles */


/* ************** UART CONTROLLER MASKS *************************/
/* Bit masks for UART Divisor Latch Registers: UARTx_DLL & UARTx_DLH */
#define UARTDLL                 0x00FF              /* Divisor Latch Low Byte */
#define UARTDLH                 0xFF00              /* Divisor Latch High Byte */

#endif /* __VISUALDSPVERSION__ <= 0x05000300 */


/****************************************************************************
 EOF
*****************************************************************************/
